marktools.BarLine
=================

.. inheritance-diagram:: abjad.tools.marktools.BarLine.BarLine.BarLine
   :private-bases:

.. autoclass:: abjad.tools.marktools.BarLine.BarLine.BarLine

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.format

   .. note:: Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.bar_line_string

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.command_name

   .. note:: Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. autoattribute:: abjad.tools.marktools.BarLine.BarLine.BarLine.format_slot

   .. note:: Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

Methods
-------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__eq__

   .. note:: Inherited from :py:class:`marktools.LilyPondCommandMark <abjad.tools.marktools.LilyPondCommandMark.LilyPondCommandMark.LilyPondCommandMark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.BarLine.BarLine.BarLine.__str__

   .. note:: Inherited from `__builtin__.object`
